@@ -19,7 +19,6 @@
 
 #include "importimapsettingnofoundpagetest.h"
 #include "../importimapsettingnofoundpage.h"
-#include "kdepimtest_layout.h"
 #include <QLabel>
 #include <QTest>
 #include <QVBoxLayout>
@@ -42,7 +41,7 @@ void ImportImapSettingNoFoundPageTest::shouldHaveDefaultValue()
 
     QVBoxLayout *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
-    KdepimTestLayout::checkContentsMargins(0, mainLayout);
+    QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 }
 
 QTEST_MAIN(ImportImapSettingNoFoundPageTest)
