@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -35,7 +35,7 @@ ServerSieveSettingsDialog::ServerSieveSettingsDialog(QWidget *parent)
     mServerSieveSettings = new ServerSieveSettings;
     connect(mServerSieveSettings, &ServerSieveSettings::enableOkButton, this, &ServerSieveSettingsDialog::slotEnableButtonOk);
     lay->addWidget(mServerSieveSettings);
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     w->setLayout(lay);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(w);
