@@ -29,7 +29,7 @@ public:
     explicit SievePurposeMenuWidget(QWidget *parentWidget, QObject *parent = nullptr);
     ~SievePurposeMenuWidget() override;
 
-    QByteArray text() override;
+    Q_REQUIRED_RESULT QByteArray text() override;
     void setEditorWidget(SieveEditorMainWidget *editor);
 private:
     SieveEditorMainWidget *mSieveEditorWidget = nullptr;
